@@ -1160,9 +1160,9 @@ class Layout:
         self.output_stream.write(value)
 
     def __write_color(self, value: datatypes.Color) -> None:
-        self.output_stream.write(struct.pack("<B", int(value.r) * 255))
-        self.output_stream.write(struct.pack("<B", int(value.g) * 255))
-        self.output_stream.write(struct.pack("<B", int(value.b) * 255))
+        self.output_stream.write(struct.pack("<B", int(value.r * 255)))
+        self.output_stream.write(struct.pack("<B", int(value.g * 255)))
+        self.output_stream.write(struct.pack("<B", int(value.b * 255)))
 
     def serialize_bridge(self):
         """
